yagamee_rcparams = {
    "font.size": 16,
    "figure.figsize": [
        14.0,
        7.0
    ],
    "xtick.labelsize": "large",
    "ytick.labelsize": "large",
    "axes.labelsize": "large",
    "xtick.direction": "in",
    "ytick.direction": "in",
    "xtick.major.size": 7,
    "ytick.major.size": 7,
    "axes.spines.top": True,
    "axes.spines.right": True,
    "axes.spines.bottom": True,
    "axes.spines.left": True,
    "axes.linewidth": 1.0,
    "legend.borderpad": 0.5,
    "legend.borderaxespad": 1.0,
    "legend.edgecolor": [
        0.2,
        0.2,
        0.2
    ]
}
